@@ -10,7 +10,7 @@ qutpn<-function(p, sigma=1, lambda=0, type=1)
     if (sigma <= 0) 
         stop("sigma must be positive")
     if (any(p <= 0 | p>=1)) 
-        stop("x's must be between 0 and 1")
+        stop("p's must be between 0 and 1")
 	if(type==1) qq=(1+sigma*(lambda+qnorm(1-p*pnorm(lambda))))^(-1)
 	if(type==2) qq=sigma*(qnorm(pnorm(lambda)*(p-1)+1))/(1+sigma*qnorm(pnorm(lambda)*(p-1)+1)+lambda)
 	if(type==3) qq=exp(sigma*(qnorm(p*pnorm(lambda))-lambda))
